import java.awt.Dimension;

import javax.media.Buffer;
import javax.media.Effect;
import javax.media.Format;
import javax.media.ResourceUnavailableException;
import javax.media.format.RGBFormat;

/**
 * @author Horst Eidenberger (hme@ims.tuwien.ac.at)
 * adaptation: Heinrich Hussmann, Bettina Conradi, Sara Streng
 * @version 1
 */
public class GrayEffect implements Effect {
	/** Supported input formats */
	private Format[] inputFormats;
	/** Supported output formats */
	private Format[] outputFormats;

	/**
	 * This is where the actual effect is implemented. The method
	 * runs through all pixels (read out of the in buffer), 
	 * manipulates them and puts them back in the out buffer.
	 * @param in in buffer
	 * @param out out buffer
	 * @return status
	 */
	public synchronized int process(Buffer in, Buffer out) {
		
		//TODO: eigenen process-Effekt implementieren
		
		// return the information that the processing was successful
		return BUFFER_PROCESSED_OK;
	}
			       
	// not needed for this simple codec
	public void open() throws ResourceUnavailableException {
	}

	// not needed for this simple codec
	public void close() {
	}

	// not needed for this simple codec
	public void reset() {
	}

	// not needed for this simple codec
	public synchronized Object getControl(String controlType) {
		return null;
	}

	// not needed for this simple codec
	public synchronized Object[] getControls() {
		return new Object[0];
	}

	/**
	 * Constructor, setting input and output formats
	 */
	public GrayEffect() {
		inputFormats = new Format[] { new RGBFormat(null, Format.NOT_SPECIFIED,
				Format.intArray, Format.NOT_SPECIFIED, 32,
				Format.NOT_SPECIFIED, Format.NOT_SPECIFIED,
				Format.NOT_SPECIFIED) };

		outputFormats = new Format[] { new RGBFormat(null,
				Format.NOT_SPECIFIED, Format.intArray, Format.NOT_SPECIFIED,
				32, Format.NOT_SPECIFIED, Format.NOT_SPECIFIED,
				Format.NOT_SPECIFIED) };
	}

	/**
	 * Return list of supported input format
	 * @return supported list of input format
	 */
	public Format[] getSupportedInputFormats() {
		return inputFormats;
	}

	/**
	 * Return list of supported output format
	 * @param input input format
	 * @return supported list of output format for a given input format
	 */
	public Format[] getSupportedOutputFormats(Format input) {
		if (input == null)
			return (outputFormats);
		if (input instanceof RGBFormat)
			return (new Format[] { input, outputFormats[0] });
		else
			return (outputFormats);
	}

	/**
	 * Set input format (if RGBFormat) or returns the default input format
	 * @param input input format
	 * @return input format
	 */
	public Format setInputFormat(Format input) {
		// declare return value
		Format inputFormat;
		
		if (input instanceof RGBFormat)
			inputFormat = input;
		else
			inputFormat = inputFormats[0];
		return (inputFormat);
	}

	/**
	 * Set output format (if RGBFormat) or returns the default output format
	 * @param output output format
	 * @return output format
	 */
	public Format setOutputFormat(Format output) {
		// declare return value
		Format outputFormat;
		
		if (output instanceof RGBFormat)
			outputFormat = output;
		else
			outputFormat = outputFormats[0];
		return (outputFormat);
	}

	/**
	 * Return name that describes the effect
	 * @return name of effect
	 */
	public String getName() {
		return "gray effect";
	}	
}
